{ config, lib, pkgs, ... }:
let
  # Define the start script
  service = "musicassistant";
  startScript = pkgs.writeScript "start-musicassistant.sh" ''
    #!/run/current-system/sw/bin/bash
    
    SERVICE=${service}

    # Update PATH
    PATH=$PATH:/run/current-system/sw/bin

    # Define version variable
    VERSION="2.3.6"

    # Define the container ID file path
    CIDFILE="/var/run/$SERVICE/$SERVICE.ctr-id"

    # Create directory if it does not exist
    mkdir -p $(dirname $CIDFILE)

    # Log the PATH
    echo "Starting $SERVICE"

    # Run the podman command
    podman run --rm \
      --cidfile=$CIDFILE \
      --name $SERVICE \
      --log-driver=journald \
      --cgroups=no-conmon \
      --sdnotify=conmon \
      -d \
      --replace \
      --cap-add=NET_RAW \
      -e TZ='America/Denver' \
      -v /config/music-assistant:/data \
      -v /run/dbus:/run/dbus:ro \
      -v /etc/localtime:/etc/localtime:ro \
      --network=guestnet \
      --dns=8.8.8.8 \
      ghcr.io/music-assistant/server

  '';
in
{
  systemd.services.${service} = {
    description = "${service} Podman Container";
    serviceConfig = {
      Type = "notify";
      NotifyAccess="all";
      ExecStart = "${startScript}";
      ExecStop = "${pkgs.podman}/bin/podman stop --ignore -t 10 --cidfile=/var/run/${service}/${service}.ctr-id";
      ExecStopPost="${pkgs.podman}/bin/podman rm -f --ignore -t 10 --cidfile=/var/run/${service}/${service}.ctr-id";
      Restart="on-failure";
      RestartSec=10;
      TimeoutStartSec=300;
      TimeoutStopSec=60;
      RemainAfterExit=true;
    };

    # Ensure that the service starts after network-related services are ready
    after = [ "network-online.target" "validate-nfs-mounts.service" ];
    requires = [ "network-online.target" "validate-nfs-mounts.service" ];

    # No need to specify startLimitIntervalSec unless you want to limit the start attempts
    startLimitIntervalSec = 0;

    # Default target is a common choice, but you might want to use multi-user.target or another suitable target
    wantedBy = [ "multi-user.target" ];
  };
}
