{ config, pkgs, ... }:
{
  # Define file systems for NFS mounts
  fileSystems."/config/hass" = {
    device = "10.10.9.14:/mnt/Storage/apps/homeassistant/hass-config";
    fsType = "nfs";
    options = [ "nfsvers=4.2" ];
  };

  fileSystems."/config/zigbee" = {
    device = "10.10.9.14:/mnt/Storage/apps/zigbee";
    fsType = "nfs";
    options = [ "nfsvers=4.2" ];
  };

  fileSystems."/config/zwave" = {
    device = "10.10.9.14:/mnt/Storage/apps/zwave";
    fsType = "nfs";
    options = [ "nfsvers=4.2" ];
  };

  fileSystems."/config/matter-bridge" = {
    device = "10.10.9.14:/mnt/Storage/apps/homeassistant/matter-bridge";
    fsType = "nfs";
    options = [ "nfsvers=4.2" ];
  };
  fileSystems."/config/music-assistant" = {
    device = "10.10.9.14:/mnt/Storage/apps/homeassistant/music-assistant";
    fsType = "nfs";
    options = [ "nfsvers=4.2" ];
  };
  # Ensure NFS client utilities are installed
  environment.systemPackages = with pkgs; [
    nfs-utils
  ];

  # Define the systemd service to create the /config directory if it doesn't exist
  systemd.services."create-config-dir" = {
    description = "Create /config directory";
    script = ''
      mkdir -p /config
    '';
    serviceConfig = {
      Type = "oneshot";
      RemainAfterExit = true;
    };
    wantedBy = [ "multi-user.target" ];
  };

  # Define the systemd service to validate NFS mounts
  systemd.services."validate-nfs-mounts" = {
    description = "Validate NFS mounts";
    after = [ "create-config-dir.service" ];
    requires = [ "create-config-dir.service" ];
    serviceConfig = {
      Type = "oneshot";
      RemainAfterExit = true;
      ExecStart = "/etc/nixos/scripts/validate-nfs-mounts.sh";
    };
    wantedBy = [ "multi-user.target" ];
  };
}
